@@ -62,9 +62,9 @@ type External struct {
 	Pull    struct {
 		Args []string `json:"args" toml:"args" yaml:"args"`
 	} `json:"pull" toml:"pull" yaml:"pull"`
-	RefreshPeriod   time.Duration `json:"refreshPeriod" toml:"refreshPeriod" yaml:"refreshPeriod"`
-	StripComponents int           `json:"stripComponents" toml:"stripComponents" yaml:"stripComponents"`
-	URL             string        `json:"url" toml:"url" yaml:"url"`
+	RefreshPeriod   Duration `json:"refreshPeriod" toml:"refreshPeriod" yaml:"refreshPeriod"`
+	StripComponents int      `json:"stripComponents" toml:"stripComponents" yaml:"stripComponents"`
+	URL             string   `json:"url" toml:"url" yaml:"url"`
 	origin          string
 }
 
@@ -1329,7 +1329,7 @@ func (s *SourceState) getExternalDataRaw(
 			var externalCacheEntry externalCacheEntry
 			if err := externalCacheFormat.Unmarshal(data, &externalCacheEntry); err == nil {
 				if externalCacheEntry.URL == external.URL {
-					if external.RefreshPeriod == 0 || externalCacheEntry.Time.Add(external.RefreshPeriod).After(now) {
+					if external.RefreshPeriod == 0 || externalCacheEntry.Time.Add(time.Duration(external.RefreshPeriod)).After(now) {
 						return externalCacheEntry.Data, nil
 					}
 				}
@@ -1889,7 +1889,10 @@ func (s *SourceState) readExternalArchive(
 		// otherwise it is not possible to differentiate between
 		// identically-named files at the same level.
 		if patternSet.match(name) == patternSetMatchExclude {
-			if fileInfo.IsDir() {
+			// In case that `name` is a directory which matched an explicit
+			// exclude pattern, return fs.SkipDir to exclude not just the
+			// directory itself but also everything it contains (recursively).
+			if fileInfo.IsDir() && len(patternSet.excludePatterns) > 0 {
 				return fs.SkipDir
 			}
 			return nil
