@@ -90,6 +90,7 @@ type ConfigFile struct {
 	Bitwarden   bitwardenConfig   `mapstructure:"bitwarden"`
 	Gopass      gopassConfig      `mapstructure:"gopass"`
 	Keepassxc   keepassxcConfig   `mapstructure:"keepassxc"`
+	Keeper      keeperConfig      `mapstructure:"keeper"`
 	Lastpass    lastpassConfig    `mapstructure:"lastpass"`
 	Onepassword onepasswordConfig `mapstructure:"onepassword"`
 	Pass        passConfig        `mapstructure:"pass"`
@@ -275,6 +276,9 @@ func newConfig(options ...configOption) (*Config, error) {
 		Keepassxc: keepassxcConfig{
 			Command: "keepassxc-cli",
 		},
+		Keeper: keeperConfig{
+			Command: "keeper",
+		},
 		Lastpass: lastpassConfig{
 			Command: "lpass",
 		},
@@ -438,6 +442,9 @@ func newConfig(options ...configOption) (*Config, error) {
 		"keepassxc":                c.keepassxcTemplateFunc,
 		"keepassxcAttachment":      c.keepassxcAttachmentTemplateFunc,
 		"keepassxcAttribute":       c.keepassxcAttributeTemplateFunc,
+		"keeper":                   c.keeperTemplateFunction,
+		"keeperDataFields":         c.keeperDataFieldsTemplateFunction,
+		"keeperFindPassword":       c.keeperFindPasswordTemplateFunc,
 		"keyring":                  c.keyringTemplateFunc,
 		"lastpass":                 c.lastpassTemplateFunc,
 		"lastpassRaw":              c.lastpassRawTemplateFunc,
@@ -1317,6 +1324,11 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		rootCmd.MarkPersistentFlagFilename("output"),
 		persistentFlags.MarkHidden("safe"),
 		rootCmd.MarkPersistentFlagDirname("source"),
+		rootCmd.RegisterFlagCompletionFunc("color", autoBoolFlagCompletionFunc),
+		rootCmd.RegisterFlagCompletionFunc("config-format", readDataFormatFlagCompletionFunc),
+		rootCmd.RegisterFlagCompletionFunc("mode", chezmoi.ModeFlagCompletionFunc),
+		rootCmd.RegisterFlagCompletionFunc("use-builtin-age", autoBoolFlagCompletionFunc),
+		rootCmd.RegisterFlagCompletionFunc("use-builtin-git", autoBoolFlagCompletionFunc),
 	} {
 		if err != nil {
 			return nil, err
