@@ -2,7 +2,6 @@ package cmd
 
 import (
 	"fmt"
-	"go/build"
 	"io"
 	"strconv"
 	"strings"
@@ -61,6 +60,7 @@ func (c *Config) runExecuteTemplateCmd(cmd *cobra.Command, args []string) error
 	}
 	if c.executeTemplate.init {
 		initTemplateFuncs := map[string]interface{}{
+			"exit": c.exitInitTemplateFunc,
 			"promptBool": func(prompt string, args ...bool) bool {
 				switch len(args) {
 				case 0:
@@ -111,12 +111,6 @@ func (c *Config) runExecuteTemplateCmd(cmd *cobra.Command, args []string) error
 			},
 			"writeToStdout": c.writeToStdout,
 		}
-		for _, releaseTag := range build.Default.ReleaseTags {
-			if releaseTag == "go1.17" {
-				initTemplateFuncs["exit"] = c.exitInitTemplateFunc
-				break
-			}
-		}
 		chezmoi.RecursiveMerge(c.templateFuncs, initTemplateFuncs)
 	}
 
